@@ -3,6 +3,9 @@
 
 #include "libsupport.h"
 #include <sys/types.h>
+#ifdef __linux__ /* Linux libc-4 needs this, libc-5 doesn't.. */
+# include <linux/limits.h>
+#endif
 #include <sys/param.h> /* Troublepotential: If somebody does not have it ? */
 #ifdef HAVE_ALLOCA_H
 # define USE_ALLOCA
@@ -14,6 +17,12 @@
 # include <stdlib.h>
 #endif
 
+/* There are systems which store the stdio fp contained fileno into
+   a SIGNED CHARACTER, and simple-minded  fileno() will therefore
+   pick FD of over 127 as negative number..  We provide a wrapper
+   for such.. */
+#define FILENO(arg) (unsigned)(fileno(arg))
+
 #ifndef	__
 # ifndef __STDC__
 #  define __(x) ()
