@@ -243,8 +243,8 @@ struct envelope {
 #define	getgrnam	zgetgrnam
 #endif	/* USE_GETPWNAM */
 
-extern struct token * scan822 __((u_char *cpp, long n, u_char c1, u_char c2,
-				  int allowcomments, struct token *tlistp));
+extern struct token * scan822 __((u_char **cpp, long n, int c1, int c2,
+				  int allowcomments, struct token **tlistp));
 extern struct token	*makeToken(), *copyToken();
 extern struct header	*makeHeader();
 extern struct header	*copySender(), *copyRecipient();
