@@ -71,6 +71,9 @@ struct ctldesc {
 	long		*offset;	/* array of indices into contents */
 	struct address	*senders;	/* list of sender addresses */
 	struct rcpt	*recipients;	/* list of selected recipients */
+	int		rcpnts_total;	/* number of recipients, total */
+	int		rcpnts_remaining;/* .. how many yet to deliver */
+	int		rcpnts_failed  ;/* .. how many failed ones */
 	char		***msgheaders;	/* pointer to all msg headers */
 	char		***msgheaderscvt; /* converted headers */
 #ifdef	USE_MMAP
@@ -122,7 +125,7 @@ extern int	       ctlsticky __((char *spec_host,char *addr_host));
 /* diagnostic.c: */
 extern char           *notaryacct __((int rc, char *okstr));
 		/* NOTARY: addres / action / status / diagnostic  */
-extern void 	       notaryreport __((char*,char*,char*,char*));
+extern void 	       notaryreport __((const char*,const char*,const char*,const char*));
 extern void	       diagnostic __((/* struct rcpt *, int, int, char *,... */));
 
 /* dnsgetrr.c */
