@@ -30,18 +30,18 @@ loginit()
 	rewind(stderr);
 	if (freopen(log, "a+", stdout) != stdout
 #ifdef	USE_DUP2
-	    || dup2(fileno(stdout), fileno(stderr)) < 0) {	/* sigh */
+	    || dup2(FILENO(stdout), FILENO(stderr)) < 0) {	/* sigh */
 #else	/* !USE_DUP2 */
-	    || (close(fileno(stderr)), dup(fileno(stdout))) < 0) { /* sigh */
+	    || (close(FILENO(stderr)), dup(FILENO(stdout))) < 0) { /* sigh */
 #endif	/* USE_DUP2 */
 		/* XX: stderr might be closed at this point... */
 		fprintf(stderr, "%s: cannot open log: %s\n", progname, log);
 		return -1;
 	}
 #if	defined(F_SETFL) && defined(O_APPEND)
-	flags = fcntl(fileno(stdout), F_GETFL, 0);
+	flags = fcntl(FILENO(stdout), F_GETFL, 0);
 	flags |= O_APPEND;
-	fcntl(fileno(stdout), F_SETFL, flags);
+	fcntl(FILENO(stdout), F_SETFL, flags);
 #endif	/* F_SETFL */
 	setvbuf(stdout, (char *)NULL, _IOLBF, 0);
 	setvbuf(stderr, (char *)NULL, _IOLBF, 0);
