@@ -204,7 +204,7 @@ mail_open(type)
 
 	/* Determine a unique id associated with the file (inode number) */
 
-	if (fstat(fileno(fp), &stbuf) < 0) {
+	if (fstat(FILENO(fp), &stbuf) < 0) {
 		eno = errno;
 		fprintf(stderr, "fstat(\"%s\"): errno %d\n", scratch, errno);
 		mail_free(scratch);
@@ -247,9 +247,9 @@ mail_open(type)
 		while (--nfile >= 0)
 			mail_file[nfile] = NULL;
 	}
-	if ((int) fileno(fp) >= mail_nfiles)
+	if (FILENO(fp) >= mail_nfiles)
 		abort();
-	mail_file[fileno(fp)] = message;
+	mail_file[FILENO(fp)] = message;
 
 	/* Grab preferences from the environment to initialize the envelope */
 
@@ -288,9 +288,9 @@ mail_abort(fp)
 		errno = EBADF;
 		return -1;
 	}
-	if ((int) fileno(fp) >= mail_nfiles)
+	if (FILENO(fp) >= mail_nfiles)
 		abort();
-	messagep = &mail_file[fileno(fp)];
+	messagep = &mail_file[FILENO(fp)];
 	if (*messagep == NULL) {
 		errno = ENOENT;
 		return -1;
@@ -325,9 +325,9 @@ mail_close(fp)
 		errno = EBADF;
 		return -1;
 	}
-	if ((int) fileno(fp) >= mail_nfiles)
+	if (FILENO(fp) >= mail_nfiles)
 		abort();
-	messagep = &mail_file[fileno(fp)];
+	messagep = &mail_file[FILENO(fp)];
 	if (*messagep == NULL) {
 		errno = ENOENT;
 		return -1;
@@ -344,7 +344,7 @@ mail_close(fp)
 	 */
 	if (fflush(fp) == EOF
 /* #ifdef NFSFSYNC */ /* This is propably ALWAYS a good idea */
-	    || fsync(fileno(fp)) < 0
+	    || fsync(FILENO(fp)) < 0
 /* #endif */	/* NFSFSYNC */
 	    || fclose(fp) == EOF) {
 		mail_free(message);
