@@ -11,6 +11,7 @@
 #include "hostenv.h"
 #if	defined(USE_HOSTS) || defined(USE_RESOLV)
 #include <netdb.h>
+#include <netinet/in.h>
 #endif	/* USE_HOSTS */
 #ifdef	USE_UNAME
 #include <sys/utsname.h>
@@ -24,6 +25,7 @@ getmyhostname(namebuf, len)
 {
 #if	defined(USE_HOSTS) || defined(USE_RESOLV)
 	struct hostent *hp;
+	struct in_addr hpaddr;
 #endif	/* USE_HOSTS */
 #ifdef	USE_UNAME
 	struct utsname id;
@@ -46,8 +48,10 @@ getmyhostname(namebuf, len)
 	}
 #if 1
 	/* enable this code if for some reason your PTR name is primary */
+	if (hp != NULL)
+	  memcpy(&hpaddr,hp->h_addr,hp->h_length);
 	if (hp != NULL
-	    && (hp = gethostbyaddr((void*)&(hp->h_addr), hp->h_length,
+	    && (hp = gethostbyaddr((void*)&hpaddr, hp->h_length,
 				   hp->h_addrtype)) != NULL) {
 		strcpy(namebuf,hp->h_name);
 	} else
