@@ -43,8 +43,8 @@ extern SIGNAL_TYPE (*orig_handler[])();
 extern char *path_hash();
 extern char *progname;
 extern char *strerror();
+extern char *strsignal();
 extern char *strnsave();
-extern const char * const sys_siglist[];
 extern int addbuffer();
 extern int errno;
 extern int interrupted;
@@ -568,7 +568,7 @@ execute(c, caller, oretcode, name)
 #ifdef	USE_UNIONWAIT
 	if (status.w_termsig) {
 		if (status.w_termsig != SIGINT) {
-			fprintf(stderr, "%s", sys_siglist[status.w_termsig]);
+			fprintf(stderr, "%s", strsignal(status.w_termsig));
 			if (status.w_coredump)
 				fprintf(stderr, CORE_DUMPED);
 		}
@@ -579,7 +579,7 @@ execute(c, caller, oretcode, name)
 #else	/* !USE_UNIONWAIT */
 	if ((status&0177) > 0) {
 		if ((status&0177) != SIGINT) {
-			fprintf(stderr, "%s", sys_siglist[status&0177]);
+			fprintf(stderr, "%s", strsignal(status&0177));
 			if (status&0200)
 				fprintf(stderr, CORE_DUMPED);
 		}
