@@ -270,7 +270,7 @@ findfreefd()
                          * and assumes these things are static as compared
                          * to shell code execution, so beware of subtle bugs.
                          */
-                        if (fstat(fd, &stbuf) == 0)
+                        if (fcntl(fd, F_GETFL,0) >= 0)
                                 continue;
 #endif  /* MAILER */
                         return fd;
@@ -1243,7 +1243,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 	/* funcall tracing could be done here */
 	/* if (caller != NULL) grindef("ARGV = ", caller->argv); */
 	if (isset('R'))
-		fds[fileno(runiofp)] = 1;
+		fds[FILENO(runiofp)] = 1;
 	for (pc = (entry == NULL ? code : entry) ; pc < eocode; ++pc) {
 		if (sprung) {
 			trapped();
