@@ -554,7 +554,7 @@ rd_doit(filename, dirs)
 #ifdef	USE_ALLOCA
 	char *buf;
 #else
-	static char *buf;
+	static char *buf = NULL;
 #endif
 	char *av[3];
 	char *p;
@@ -581,7 +581,7 @@ rd_doit(filename, dirs)
 	  }
 	  /* Probe it!
 	     Does the process exist ? */
-	  if (thatpid && kill(thatpid,0)==0) {
+	  if (thatpid && kill(thatpid,0)==0 && thatpid != router_id) {
 	    /*
 	     * an already locked message file,
 	     * belonging to another process
@@ -600,7 +600,7 @@ rd_doit(filename, dirs)
 	     */
 	  }
 	}
-	if (p == NULL || thatpid != getpid()) {
+	if (p == NULL || thatpid != router_id) {
 	  /* Not already in format of 'inode-pid' */
 	  /* If the pid did exist, we do not touch on that file,
 	     on the other hand, we need to rename the file now.. */
@@ -616,9 +616,12 @@ rd_doit(filename, dirs)
 	    buf = (char *)realloc(buf, blen);
 	  }
 #endif
-	  sprintf(buf, "%s-%d", filename, getpid());
+	  if (p) *p = 0;
+	  sprintf(buf, "%s-%d", filename, router_id);
+	  if (p) *p = '-';
 	  if (eqrename(pathbuf, buf, 1) < 0)
-	    return 0;		/* something is wrong, erename() complains */
+	    return 0;		/* something is wrong, erename() complains.
+				   (some other process picked it ?) */
 	  filename = buf;
 	  /* message file is now "file-#" and belongs to this process */
 	}
