@@ -63,13 +63,13 @@ reopen:
 		fm = (struct file_map *)emalloc(sizeof(struct file_map));
 		fm->fp = fp;
 #ifdef	USE_MMAP
-		fstat(fileno(fp),&fst);
+		fstat(FILENO(fp),&fst);
 		fm->size = fst.st_size;
 		fm->mtime = fst.st_mtime;
 		fm->lines = 0;
 		fm->offsets = NULL;
 		fm->membuf = (void*)mmap(NULL, fst.st_size,
-					 PROT_READ, MAP_SHARED, fileno(fp), 0);
+					 PROT_READ, MAP_SHARED, FILENO(fp), 0);
 		if ((long)fm->membuf == -1) {
 			fprintf(stderr,
 				"search_bin: cannot mmap() (r/o) %d bytes of file \"%s\" into memory, errno=%d",
@@ -101,8 +101,8 @@ reopen:
 	   possible upper-level "-m"..					*/
 #define NO_SEQREMAP
 #ifndef NO_SEQREMAP
-	if (fstat(fileno(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
-	if (fstat(fileno(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
+	if (fstat(FILENO(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
+	if (fstat(FILENO(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
 	if (fst.st_mtime != fm->mtime ||
 	    fst.st_size  != fm->size) {
 		/* Changes at the original file, remap.. */
