@@ -24,7 +24,7 @@ struct file_map {
 	time_t	mtime;		/* Last modification time	*/
 	long	size;		/* File size			*/
 	long	pos;		/* Position in file...		*/
-	void	*membuf;	/* MMAPed buffer start		*/
+	char	*membuf;	/* MMAPed buffer start		*/
 	int	lines;		/* Count of lines on the file	*/
 	int	*offsets;	/* Array of line begin offsets	*/
 };
