@@ -63,13 +63,13 @@ reopen:
 		fm = (struct file_map *)emalloc(sizeof(struct file_map));
 		fm->fp = fp;
 #ifdef	USE_MMAP
-		fstat(fileno(fp),&fst);
+		fstat(FILENO(fp),&fst);
 		fm->size = fst.st_size;
 		fm->mtime = fst.st_mtime;
 		fm->lines = 0;
 		fm->offsets = NULL;
 		fm->membuf = (void*)mmap(NULL, fst.st_size,
-					 PROT_READ, MAP_SHARED, fileno(fp), 0);
+					 PROT_READ, MAP_SHARED, FILENO(fp), 0);
 		if ((long)fm->membuf == -1) {
 			fprintf(stderr,
 				"search_seq: cannot mmap() (r/o) %d bytes of file \"%s\" into memory, errno=%d",
@@ -102,7 +102,7 @@ reopen:
 	   possible upper-level "-m"..					*/
 #define NO_SEQREMAP
 #ifndef NO_SEQREMAP
-	if (fstat(fileno(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
+	if (fstat(FILENO(fp),&fst) < 0) abort(); /* Will succeed, or crash.. */
 	if (fst.st_mtime != fm->mtime ||
 	    fst.st_size  != fm->size) {
 		/* Changes at the original file, remap.. */
@@ -221,13 +221,13 @@ open_seq(sip, mode)
 		fm = (struct file_map *)emalloc(sizeof(struct file_map));
 		fm->fp = fp;
 #ifdef	USE_MMAP
-		fstat(fileno(fm->fp),&fst);
+		fstat(FILENO(fm->fp),&fst);
 		fm->size = fst.st_size;
 		fm->mtime = fst.st_mtime;
 		fm->lines = 0;
 		fm->offsets = NULL;
 		fm->membuf = (void*)mmap(NULL, fst.st_size,
-					 PROT_READ, MAP_SHARED, fileno(fm->fp), 0);
+					 PROT_READ, MAP_SHARED, FILENO(fm->fp), 0);
 #else
 		fm->size   = 0;
 		fm->mtime  = 0;
@@ -298,7 +298,7 @@ owner_seq(sip, outfp)
 	if (sip->file == NULL || (fp = open_seq(sip, "r")) == NULL)
 		return;
 
-	if (fstat(fileno(fp), &stbuf) < 0) {
+	if (fstat(FILENO(fp), &stbuf) < 0) {
 		fprintf(stderr, "owner_seq: cannot fstat(\"%s\")!\n",
 			sip->file);
 		return;
@@ -320,7 +320,7 @@ modp_seq(sip)
 	if (sip->file == NULL || (fp = open_seq(sip, "r")) == NULL)
 		return 0;
 
-	if (fstat(fileno(fp), &stbuf) < 0) {
+	if (fstat(FILENO(fp), &stbuf) < 0) {
 		fprintf(stderr, "modp_seq: cannot fstat(\"%s\")!\n",
 				sip->file);
 		return 0;
@@ -348,7 +348,7 @@ long newsize;
 	if (fm->membuf != NULL)
 		munmap(fm->membuf, fm->size);
 	fm->membuf = (void*)mmap(NULL, newsize,
-				 PROT_READ, MAP_SHARED, fileno(fm->fp), 0);
+				 PROT_READ, MAP_SHARED, FILENO(fm->fp), 0);
 	fm->size = newsize;
 	if (fm->offsets != NULL)
 	  free(fm->offsets);
