@@ -106,11 +106,11 @@ run_rfc822(argc, argv)
 		status = PERR_BADOPEN;
 	} else {
 /* XX: DEBUG STUFF! */
-if (FILENO(e->e_fp) < 4) {
-  fprintf(stderr,"RFC822: While opening mail-file '%s', got fd=%d  AARGH! (abort!)",
+if (FILENO(e->e_fp) < 3) {
+  fprintf(stderr,"RFC822: While opening mail-file '%s', got fd=%d  AARGH! (fds 0..2 should never close on us!)",
 	  file, FILENO(e->e_fp));
   fflush(stderr);
-  abort();
+  /* abort(); */
 }
 		status = PERR_OK;
 		setvbuf(e->e_fp, buf, _IOFBF, sizeof buf);
