@@ -25,7 +25,9 @@
 
 extern char *strchr();
 extern char *strrchr();
+#ifndef strnsave /* unless it is a debugging macro.. */
 extern char *strnsave();
+#endif
 extern int errno;
 
 /*
