@@ -14,12 +14,16 @@
 #if 0
 /* *** DEBUGGING STUFF! *** */
 
-static void *emalloc(size) size_t size; { void *ptr = malloc(size); fprintf(stderr,"mal: siz=%d ptr=0x%p\n",size,ptr); return ptr; }
-static void *erealloc(ptr,size) void *ptr; size_t size; {void *newptr = realloc(ptr,size);fprintf(stderr,"mal: realloc(0x%p,%d)->0x%p\n",ptr,size,newptr);return newptr; }
-static char *strsave(s) const char *s; { char *s2 = emalloc(strlen(s)+1); strcpy(s2,s); return s2;}
-static char *strnsave(s,len) const char *s; const size_t len; { char *s2 = emalloc(len+1); strncpy(s2,s,len); s2[len] = 0; return s2;}
-static void _free(ptr,file,line) void *ptr; char*file;int line; { fprintf(stderr,"%s:%d:mal: free(0x%p)\n",file,line,ptr); free(ptr); }
-#define free(ptr) _free(ptr,__FILE__,__LINE__)
+static void *__emalloc(size,fil,lin) size_t size; char *fil; int lin; { void *ptr = malloc(size); fprintf(stderr,"%s:%d:mal: siz=%d ptr=0x%p\n",fil,lin,size,ptr); return ptr; }
+#define emalloc(size) __emalloc(size,__FILE__,__LINE__)
+static void *__erealloc(ptr,size,fil,lin) void *ptr; size_t size; char*fil;int lin; {void *newptr = realloc(ptr,size);fprintf(stderr,"%s:%d:mal: realloc(0x%p,%d)->0x%p\n",fil,lin,ptr,size,newptr);return newptr; }
+#define erealloc(ptr,size) __erealloc(ptr,size,__FILE__,__LINE__)
+static char *__strsave(s,fil,lin) const char *s;char *fil; int lin; { char *s2 = __emalloc(strlen(s)+1,fil,lin); strcpy(s2,s); return s2;}
+#define strsave(s) __strsave(s,__FILE__,__LINE__)
+static char *__strnsave(s,len,fil,lin) const char *s; const size_t len; char *fil; int lin; { char *s2 = __emalloc(len+1,fil,lin); strncpy(s2,s,len); s2[len] = 0; return s2;}
+#define strnsave(s,n) __strnsave(s,n,__FILE__,__LINE__)
+static void __free(ptr,file,line) void *ptr; char*file;int line; { fprintf(stderr,"%s:%d:mal: free(0x%p)\n",file,line,ptr); free(ptr); }
+#define free(ptr) __free(ptr,__FILE__,__LINE__)
 
 #endif
 
@@ -106,6 +110,7 @@ extern void  thread_reschedule __((struct thread *, time_t, int index));
 extern struct procinfo *cpids;
 extern int  numkids;
 extern void feed_child      __((struct procinfo *cpidp));
+extern void idle_child      __((struct procinfo *cpidp));
 extern int  start_child     __((struct vertex *vhead, struct web *channel, struct web *host));
 extern SIGNAL_TYPE sig_chld __((int sig));
 extern int mux __((time_t timeout));
