@@ -18,7 +18,7 @@
 /* define NO_VERBOSE_MAILQ, if you don't want to output potentially HUGE
    mailq report -- necessary at some sites, while definitely undesirable
    at others..  We need to change this mechanism.. */
-#define NO_VERBOSE_MAILQ
+/* #define NO_VERBOSE_MAILQ */
 
 extern int errno;
 extern time_t time();
