@@ -30,20 +30,26 @@ struct config_entry {
 	int	uid;		/* what uid to run the transport agent under */
 	int	gid;		/* what gid to run the transport agent under */
 	char	*command;	/* the command to run			     */
+	int	flags;		/* miscellaneous flags			     */
+#define CFG_BYCHANNEL 0x0001
+#define CFG_WITHHOST  0x0002
+#define CFG_AGEORDER  0x0004	/* In order of the ctlfile->ctime -fields    */
+#if 0
 	int	bychannel;	/* indicates $channel occurs in command      */
 	int	withhost;	/* indicated $host occurs in command	     */
-	int	flags;		/* miscellaneous flags			     */
+	int	ctlageorder;	/* run attempts on oldest-first basis	     */
+#endif
 	int	maxkids;	/* run command only if # TA's running < this */
 	int	maxkidChannel;	/* run only if # TA's running channel < this */
 	int	maxkidThreads;	/*run only if # TA's running thread-ring<this*/
 	int	idlemax;	/* max time to keep idle ta-procs around     */
 	int	skew;		/* retry skew parameter			     */
 	int	mark;		/* non-0 if we started a TA the last time    */
-	int	pending;	/* non-0 if TA fork would go over limits     */
+	int	overfeed;	/* How much overfeeding instead of sync processing ? */
 	char	**argv;		/* execv parameters for the command	     */
 	int	nretries;	/* number of retry factors known	     */
 	int	*retries;	/* list of nretries retry factors	     */
-	char	*deliveryform;	/* [mea] Name of delivery error form	     */
+	char	*deliveryform;	/* name of delivery error form		     */
 };
 
 #define	L_CTLFILE	0
@@ -73,6 +79,9 @@ struct ctlfile {
 	char	*envid;		/* DSN envid				     */
 	u_long	id;		/* identification # (inode# of control file) */
 	char	*mid;		/* msg identification (name of message file) */
+	int	rcpnts_total;	/* how many recipients all in all ?	     */
+	int	rcpnts_failed;	/* .. failed ones of them ?		     */
+	int	rcpnts_work;	/* .. yet to deliver ?			     */
 	int	mark;		/* flag used by selector() to pass filenames */
 	int	msgbodyoffset;	/* size of original headers to skip on errrpt*/
 	long	offset[1];	/* array of nlines byte offsets into the file*/
@@ -90,6 +99,7 @@ struct threadgroup {
 	struct thread	*thread;	/* Any of the threads in the group  */
 	struct threadgroup *next, *prev; /* Ring of thread groups	    */
 	struct config_entry *cep;	/* Pointer to a config database     */
+	struct config_entry ce;		/* consed scheduler config file entry*/
 };
 
 struct thread {
@@ -97,6 +107,8 @@ struct thread {
 	int		attempts;	/* How many times activated ?	    */
 	int		retryindex;	/* when, what ?			    */
 	char		*channel, *host; /* documenting */
+	struct web	*wchan;		/* Web of CHANNELs		    */
+	struct web	*whost;		/* Web of HOSTs			    */
 	struct thread	*nexttr;	/* Next one in threads queue	    */
 	struct thread	*prevtr;	/* previous one ...		    */
 	struct thread	*nextthg;	/* Next one in thread GROUP	    */
@@ -124,6 +136,8 @@ struct procinfo {
 	int	hungry;		/* State of reports from child		*/
 	time_t	hungertime;	/* .. when presented			*/
 	int	fed;
+	int	overfed;	/* Now many jobs fed to it over the normal 1?*/
+	time_t	feedtime;	/* .. when fed				*/
 	struct web *ch;		/* Web of CHANNELs			*/
 	struct web *ho;		/* Web of HOSTs				*/
 	struct thread *thread;	/* The thread we are processing		*/
@@ -131,6 +145,7 @@ struct procinfo {
 	struct procinfo *next;	/* next one in IDLE queue		*/
 	struct threadgroup *thg; /* The thread-ring we are in		*/
 	char	*carryover;	/* Long responces..			*/
+	char	cmdbuf[1000];	/* outgoing pipe leftovers..		*/
 };
 
 /* Stores the offset indices of all addresses that have same channel and host*/
@@ -138,11 +153,11 @@ struct procinfo {
 struct vertex {		
 	struct ctlfile	*cfp;		/* control file containing this group*/
 	int		qid;		/* mailq report id - filled at qprint*/
-	int		linkcnt;
 	struct web	*orig[SIZE_L];	/* original names (channel,host,etc) */
 	struct vertex	*next[SIZE_L];	/* next group with same L_?	     */
 	struct vertex	*prev[SIZE_L];	/* previous group with same L_?      */
 	struct thread	*thread;	/* the thread we are in		     */
+	struct threadgroup *thgrp;	/* the group we are in		     */
 	struct vertex	*nextitem;	/* next in list of scheduled vertices*/
 	struct vertex	*previtem;	/* prev in list of scheduled vertices*/
 	char		*message;	/* some text associated with node    */
@@ -151,7 +166,8 @@ struct vertex {
 	char		*notary;	/* IETF Notary report data	     */
 	char		*dnsrecipient;	/*				     */
 
-	struct config_entry ce;		/* consed scheduler config file entry*/
+	int		ce_pending;	/* pending on what ?		     */
+	time_t		ce_expiry;	/* when this vertex expires ?        */
 	struct procinfo *proc;		/* current TA process description    */
 	int		attempts;	/* count of number of TA invocations */
 	int		retryindex;	/* cur index into ce->retries array  */
