@@ -29,6 +29,7 @@ static struct threadgroup *thrg_root   = NULL;
 int idleprocs = 0;
 extern int global_wrkcnt;
 extern int syncstart;
+extern time_t now;
 
 struct threadgroup *
 create_threadgroup(cep, wc, wh, withhost, ce_fillin)
@@ -246,6 +247,7 @@ int ok;
 	    thg->idleproc     = thr->proc;
 	    /* thr->proc      = NULL; */ /* The `thr' goes into `free()' */
 	    thg->idlecnt     += 1;
+	    idle_child(thr->proc);
 	    ++idleprocs;
 	  } else if (thr->proc != NULL &&
 		     thr->proc->pid <= 0) {
@@ -275,6 +277,7 @@ int ok;
 	    proc->next = thg->idleproc;
 	    thg->idleproc = proc;
 	    thg->idlecnt += 1;
+	    idle_child(thr->proc);
 	    ++idleprocs;
 	    if (verbose)
 	      fprintf(stderr, "delete_thread(2) thr->proc=0x%p pid=%d ",
@@ -289,6 +292,7 @@ int ok;
 	      if (thr1->proc == NULL ||
 		  thr1->proc->thread != thr1) {
 		/* Ok, this thread is not busy, choose it! */
+		time(&now);
 		thread_start(thr1);
 		break;
 	      }
@@ -361,6 +365,8 @@ void (*ce_fillin) __((struct threadgroup*, struct config_entry *));
 	struct web *wc = vp->orig[L_CHANNEL];
 	struct web *wh = vp->orig[L_HOST];
 
+	time(&now);
+
 if (verbose) printf("thread_linkin([%s/%s],%s/%d/%s,%d)\n",wc->name,wh->name,
 		    cep->channel,cep->flags & CFG_WITHHOST,cep->host,cfgid);
 
@@ -431,13 +437,15 @@ if (verbose) printf("thread_linkin() to thg=0x%p[%s/%d/%s]; added into existing
 	  }
 	  /* No matching thread, however this GROUP matches (or does it?) */
 
-if (verbose) printf("thread_linkin() to thg=0x%p[%s/%d/%s]; created a new thread [%s/%s]\n",
-		    thg,cep->channel,thg->withhost,cep->host,
-		    wc->name,wh->name);
-
 	  /* Add a new thread into this group */
 	  thr = create_thread(thg,vp,cep);
 	  vp->thgrp = thg;
+
+if (verbose) printf("thread_linkin() to thg=0x%p[%s/%d/%s]; created a new thread 0x%p [%s/%s]\n",
+		    thg,cep->channel,thg->withhost,cep->host,
+		    thr,wc->name,wh->name);
+
+
 	  /* Try to start it too */
 	  thread_start(thr);
 	  return;
@@ -732,11 +740,14 @@ struct thread *thr;
 	  proc->fed = 0;
 	  /* Its idle process, feed it! */
 	  feed_child(proc);
+	  if (proc->fed)
+	    proc->overfed += 1;
 	  proc->hungry = 1;	/* Simulate hunger.. */
 	  pick_next_vertex(proc,1);
-	  for (;;) {
-	    proc->hungry = 1;
-	    feed_child(proc);
+	  /* While we have a thread, and things to feed.. */
+	  while (!proc->fed && proc->thread) {
+	    if (proc->hungry)
+	      feed_child(proc);
 	    if (proc->fed)
 	      proc->overfed += 1;
 	    /* See if we should, and can feed more! */
@@ -749,10 +760,10 @@ struct thread *thr;
 	    if (proc->overfed >= proc->thg->ce.overfeed)
 	      break;		/* if the limit is zero, don't overfeed ever.*/
 	    /* Ok, increment the counter, and loop back.. */
-	    proc->fed = 1;	/* tell the picker, it has been fed.. */
+	    proc->hungry = 1;	/* Simulate hunger.. */
+	    proc->fed = 1;	/* tell them, it has been fed.. */
 	    pick_next_vertex(proc,1);
-	    if (proc->fed != 0) /* Out of jobs in this thread.. */
-	      break;
+	    /* If it got next,  ``proc->fed'' is now zero.. */
 	  }
 	  proc->hungry = 0; /* ... satiated.. */
 	  return 1;
@@ -936,15 +947,26 @@ if (verbose) printf(" ... thr=0x%p vtx=0x%p ch=%s ho=%s\n",
 	  return; /* It is eligible to run! */
 	}
 
+	if (proc->overfed > 0 && proc->fed) {
+	  /* we have an overfeed situation, we are to stop at
+	     the end of the thread, and wait thread purge to
+	     happen -- by timeouts, or whatever.
+	     We don't idle, we don't move, just return.. */
+if (verbose) printf(" ... OVERFEED - don't change thread yet.\n");
+	  return;
+	}
+
 	/* No free threads/vertices here, idle the process */
+if (verbose) printf(" ... NONE, idle the process (of=%d, f=%d).\n",
+		    proc->overfed, proc->fed);
 	proc->thread = NULL;
 	proc->vertex = NULL;
 	proc->next = thg->idleproc;
 	thr0->proc = NULL;
 	thg->idleproc = proc;
 	thg->idlecnt += 1;
+	idle_child(proc);
 	++idleprocs;
-if (verbose) printf(" ... NONE, idle the process.\n");
 }
 
 /*
@@ -1266,7 +1288,7 @@ if (verbose) printf("idle_cleanup()\n");
 		p->thg        = NULL;
 		p->thread     = NULL;
 		thg->idlecnt -= 1;
-		idleprocs    -= 1;
+		--idleprocs;
 		++freecount;
 		/* The thread-group can be deleted before reclaim() runs! */
 		thg->transporters -= 1;
@@ -1337,6 +1359,7 @@ FILE *fp;
 		    /* thr->vertices->orig[L_HOST]->name, */ thr->host,
 		    thr->thgrp->withhost,thr->jobs);
 	    jobsum += thr->jobs;
+	    fprintf(fp," ats=%d",thr->attempts);
 	    ++cnt;
 	    if (thr->proc != NULL &&
 		thr->proc->thread == thr) {
