@@ -52,6 +52,13 @@ extern time_t time();
 
 
 
+void
+idle_child(proc)
+struct procinfo *proc;
+{
+	/* XX: send "#idle\n" -string to the child.. */
+}
+
 void
 feed_child(proc)
 struct procinfo *proc;
@@ -103,6 +110,13 @@ struct procinfo *proc;
 	if (verbose)
 	  printf("feed: tofd=%d, fed=%d, len=%d, chan=%s, buf=%s",
 		 proc->tofd,proc->fed,len,proc->ch->name,proc->cmdbuf);
+	if (proc->fed) {
+	  /* DON'T RE-FEED! */
+	  proc->cmdbuf[0] = 0;
+	  if (verbose)
+	    printf(" ... no refeeding\n");
+	  return;
+	}
 
 	rc = write(proc->tofd, proc->cmdbuf, len);
 
