@@ -110,7 +110,8 @@ update(fd, diagnostic)
 		/* Unless it is still overfed,
 		   Pick next, and feed it! */
 		pick_next_vertex(proc,1);
-		for (;;) {
+		/* While we have a thread, and things to feed.. */
+		while (!proc->fed && proc->thread) {
 		  if (proc->hungry)
 		    feed_child(proc);
 		  if (proc->fed)
@@ -126,10 +127,9 @@ update(fd, diagnostic)
 		    break;	/* if the limit is zero, don't overfeed ever.*/
 		  /* Ok, increment the counter, and loop back.. */
 		  proc->hungry = 1; /* Simulate hunger.. */
-		  proc->fed = 1;    /* tell them, it has been fed.. */
+		  proc->fed = 1; /* tell them, it has been fed.. */
 		  pick_next_vertex(proc,1);
-		  if (proc->fed != 0) /* Out of jobs in this thread.. */
-		    break;
+		  /* If it got next,  ``proc->fed'' is now zero.. */
 		}
 		proc->hungry = 0; /* ... satiated.. */
 	      } else {
@@ -250,9 +250,16 @@ void unvertex(vp, justfree, ok)
 	  return;
 
 	if (vp->proc && vp->proc->vertex == vp) {
-	  vp->proc->fed = 1; /* Mark it fed just in case.. */
+	  vp->proc->fed = 1;     /* Mark it fed just in case.. */
+	  vp->proc->overfed = 0; /* .. and clear this .. */
 	  /* Pick next, but don't feed it (yet)! */
 	  pick_next_vertex(vp->proc, ok);
+	  if (vp->proc && vp->proc->vertex == vp){
+	    fprintf(stderr,
+		    "unvertex(vtx=0x%p,%d,%d) failed to pick_next_vertex()!\n",
+		    vp,justfree,ok);
+	    abort();
+	  }
 	}
 
 	for (i = 0; i < SIZE_L; ++i) {
