@@ -1721,12 +1721,12 @@ help(cfinfo, query)
 		TYPE_(Copyright);
 		TYPE_(Copyright2);
 		TYPE_("");
-		printf("241-The following commands are recognized:");
+		TYPE_("The following commands are recognized:");
 		col = 100;
 		for (carp = &command_list[0]; carp->verb != NULL; ++carp) {
 			if (col > 70) {
 				col = 12;
-				printf("\r\n241-\t%s", carp->verb);
+				printf("\r\n214-\t%s", carp->verb);
 			} else {
 				printf(", %s", carp->verb);
 				col += 6;
@@ -1739,9 +1739,9 @@ help(cfinfo, query)
 		TYPE_("This mailer always accepts 8-bit and binary message data");
 		TYPE_("though you are better to use MIME format!");
 		TYPE_("");
-		printf("241-For local information contact: ");
+		printf("214-For local information contact: ");
 		printf("postmaster@%s\r\n", myhostname);
-		printf("241 SMTP server comments and bug reports to: ");
+		printf("214 SMTP server comments and bug reports to: ");
 		printf("zmhacks@nic.funet.fi\r\n");
 		break;
 	}
