@@ -2419,12 +2419,12 @@ GenerateOutputTable(typeName)
 	char *typeName;
 {
 	OutputAddress i;
-	int col = 8, coladd;
+	int col = 16, coladd;
 
 	/* Generate Syntax/Semantic Table */
 	fprintf(tablefp, "/* S/SL table (%d entries) */\n",
 			    outputPointer);
-	fprintf(tablefp, "\n%s sslTable[] = {\n\t", typeName ? typeName:"int");
+	fprintf(tablefp, "\n%s sslTable[] = {\n/* %4d */\t", typeName ? typeName:"int", 0);
 
 
 	for (i = 0; i < outputPointer; ++i) {
@@ -2436,8 +2436,8 @@ if (outputNameTable[i] && outputNameTable[i][0] == '"')
 		else
 		  coladd = 7;
 		if (col+coladd > 78) {
-			fprintf(tablefp, "\n\t");
-			col = 8;
+			fprintf(tablefp, "\n/* %4d */\t",i);
+			col = 16;
 		}
 		col += coladd;
 	        if (outputNameTable[i] != NULL)
