@@ -8,6 +8,12 @@
 # include <sys/types.h>
 # endif
 
+#ifdef SYSV
+# define index strchr
+# define rindex strrchr
+# define bcopy(a,b,c) memcpy(b,a,c)
+#endif
+
 /* support for bool type */
 typedef char	bool;
 # define TRUE	1
@@ -40,15 +46,18 @@ typedef char	bool;
 
 /* sccs id's */
 # ifndef lint
-# define SCCSID(arg)	static char SccsId[] = "arg";
+#  ifdef __STDC__
+#   define SCCSID(arg)  static char SccsId[] = "" ## arg ; /* ANSI notation */
+#  else
+#   define SCCSID(arg)	static char SccsId[] = "arg";
+# endif
 # else lint
-# define SCCSID(arg)
+#  define SCCSID(arg)
 # endif lint
 
 /* define the types of some common functions */
 extern char	*strcpy(), *strncpy();
 extern char	*strcat(), *strncat();
-extern char	*malloc();
 extern char	*index(), *rindex();
 extern int	errno;
 extern time_t	time();
