@@ -200,6 +200,8 @@ main(argc, argv)
 	    break;
 	  if (strchr(file, '\n') == NULL) break; /* No ending '\n' !  Must
 						    have been partial input! */
+	  if (strcmp(file, "#idle\n") == 0)
+	    continue; /* Ah well, we can stay idle.. */
 	  if (emptyline(file, sizeof file))
 	    break;
 
@@ -214,8 +216,6 @@ main(argc, argv)
 	    process(dp);
 	    ctlclose(dp);
 	  }
-break; /* XXX: Unfortunately, hold appears to hung somewhat, when doing
-		multiple accesses.. */
 	}
 	exit(0);
 	/* NOTREACHED */
