@@ -20,6 +20,7 @@ extern void *emalloc();
 extern void *erealloc();
 
 char *notarybuf = NULL;
+time_t retryat_time = 0; /* Used at SMTP to avoid trying same host too soon.. */
 
 char *
 notaryacct(rc,okstr)
@@ -59,7 +60,7 @@ char *host;
 
 void
 notaryreport(arg1,arg2,arg3,arg4)
-	char *arg1, *arg2, *arg3, *arg4;
+     const char *arg1, *arg2, *arg3, *arg4;
 {
 	char *fmt = "%s\001%s\001%s\001%s\001%s";
 	int len;
@@ -134,6 +135,8 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 	*s = '\0';
 	va_end(ap);
 
+	retryat_time = 0;
+
 	printf("%d/%ld\t%s\t",
 	       rp->desc->ctlid, rp->id, notarybuf ? notarybuf : "");
 	switch (rp->status) {
@@ -146,8 +149,11 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 	case EX_OSERR:
 	case EX_CANTCREAT:
 	case EX_SOFTWARE:
-		if (timeout > 0)
+		if (timeout > 0) {
 		  printf("retryat +%d",timeout);
+		  time(&retryat_time);
+		  retryat_time += timeout;
+		}
 		else
 		  printf("deferred");
 		mark = _CFTAG_DEFER;
