@@ -27,19 +27,19 @@ lockaddr(fd, offset, was, new)
 	int	newlock = 0;
 
 	if (lseek(fd, offset, L_SET) < 0L) {
-		(void) fprintf(stderr, "lockaddr: lseek failure\n");
-		return 0;
+	  warning("lockaddr: lseek() failure");
+	  return 0;
 	}
 	if (read(fd, lockbuf, sizeof(lockbuf)) != sizeof(lockbuf)) {
-		(void) fprintf(stderr, "lockaddr: read failure\n");
-		return 0;
+	  warning("lockaddr: read() failure");
+	  return 0;
 	}
 	newlock = ((lockbuf[1] == ' ') ||
 		   (lockbuf[1] >= '0' && lockbuf[1] <= '9'));
 	if (lockbuf[0] == was) {
 		if (lseek(fd, offset, L_SET) < 0L) {
-			fprintf(stderr, "lockaddr: lseek2 failure\n");
-			return 0;
+		  warning("lockaddr: lseek() failure 2");
+		  return 0;
 		}
 		if (write(fd, &new, 1) != 1) return 0;
 		if (newlock) {
@@ -57,7 +57,7 @@ lockaddr(fd, offset, was, new)
 		}
 		return 1;
 	}
-	fprintf(stderr, "lockaddr: expected '%c' found '%c'\n", was, new);
+	warning("lockaddr: expected '%c' found '%c'\n", was, new);
 	return 0;
 }
 
