@@ -22,7 +22,7 @@ warning(fmt, arg, arg2, arg3, arg4)
 	int e = errno; /* Save it over the openlog() .. */
 
 	if (progname != NULL)
-		(void) fprintf(stderr, "%s: ", progname);
+		(void) fprintf(stderr, "# %s:%d: ", progname, getpid());
 	fprintf(stderr, fmt, arg, arg2, arg3, arg4);
 	fprintf(stderr, "\n");
 #if	defined(BSD) || defined(sun)
