@@ -209,6 +209,8 @@ main(argc, argv)
 	    break;
 	  if (strchr(file, '\n') == NULL) break; /* No ending '\n' !  Must
 						    have been partial input! */
+	  if (strcmp(file, "#idle\n") == 0)
+	    continue; /* Ah well, we can stay idle.. */
 	  if (emptyline(file, sizeof file))
 	    break;
 
