@@ -490,7 +490,10 @@ main(argc, argv)
 	  if (fgets(file, sizeof file, stdin) == NULL) break;
 	  if (strchr(file, '\n') == NULL) break; /* No ending '\n' !  Must
 						    have been partial input! */
-
+	  if (logfp)
+	    fprintf(logfp,"%s#\tjobspec: %s",logtag(),file);
+	  if (strcmp(file, "#idle\n") == 0)
+	    continue; /* XX: We can't stay idle for very long, but.. */
 	  if (emptyline(file, sizeof file))
 	    break;
 
